WireErrorCode

Enum WireErrorCode 

pub enum WireErrorCode {
Show 17 variants NoError = 0, InternalError = 1, ConnectionRefused = 2, FlowControlError = 3, StreamLimitError = 4, StreamStateError = 5, FinalSizeError = 6, FrameEncodingError = 7, TransportParameterError = 8, ConnectionIdLimitError = 9, ProtocolViolation = 10, InvalidToken = 11, ApplicationError = 12, CryptoBufferExceeded = 13, KeyUpdateError = 14, AeadLimitReached = 15, NoViablePath = 16,
}
QUIC error codes sent on the wire.

As defined in RFC9000.

Variants



NoError = 0

An endpoint uses this with CONNECTION_CLOSE to signal that the connection is being closed abruptly in the absence of any error.



InternalError = 1

The endpoint encountered an internal error and cannot continue with the connection.



ConnectionRefused = 2

The server refused to accept a new connection.



FlowControlError = 3

An endpoint received more data than it permitted in its advertised data limits; see Section 4.



StreamLimitError = 4

An endpoint received a frame for a stream identifier that exceeded its advertised stream limit for the corresponding stream type.



StreamStateError = 5

An endpoint received a frame for a stream that was not in a state that permitted that frame.



FinalSizeError = 6

(1) An endpoint received a STREAM frame containing data that exceeded the previously established final size, (2) an endpoint received a STREAM frame or a RESET_STREAM frame containing a final size that was lower than the size of stream data that was already received, or (3) an endpoint received a STREAM frame or a RESET_STREAM frame containing a different final size to the one already established.



FrameEncodingError = 7

An endpoint received a frame that was badly formatted โ€“ for instance, a frame of an unknown type or an ACK frame that has more acknowledgment ranges than the remainder of the packet could carry.



TransportParameterError = 8

An endpoint received transport parameters that were badly formatted, included an invalid value, omitted a mandatory transport parameter, included a forbidden transport parameter, or were otherwise in error.



ConnectionIdLimitError = 9

The number of connection IDs provided by the peer exceeds the advertised active_connection_id_limit.



ProtocolViolation = 10

An endpoint detected an error with protocol compliance that was not covered by more specific error codes.



InvalidToken = 11

A server received a client Initial that contained an invalid Token field.



ApplicationError = 12

The application or application protocol caused the connection to be closed.



CryptoBufferExceeded = 13

An endpoint has received more data in CRYPTO frames than it can buffer.



KeyUpdateError = 14

An endpoint detected errors in performing key updates.



AeadLimitReached = 15

An endpoint has reached the confidentiality or integrity limit for the AEAD algorithm used by the given connection.



NoViablePath = 16

An endpoint has determined that the network path is incapable of supporting QUIC. An endpoint is unlikely to receive a CONNECTION_CLOSE frame carrying this code except when the path does not support a large enough MTU.