pub struct SendInfo {
pub from: SocketAddr,
pub to: SocketAddr,
pub at: Instant,
}Expand description
Ancillary information about outgoing packets.
Fields
from: SocketAddrThe local address the packet should be sent from.
to: SocketAddrThe remote address the packet should be sent to.
at: InstantThe time to send the packet out.
See Pacing for more details.